==> open-xchange-server_6.14.0.0.orig.tar.gz: open-xchange-server-6.14.0.0/src/com/openexchange/ajax/parser/CommonParser.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */



package com.openexchange.ajax.parser;

import java.util.TimeZone;

import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.ajax.fields.CommonFields;
import com.openexchange.groupware.container.CommonObject;
import com.openexchange.tools.servlet.OXJSONException;

/**
 * CommonParser
 *
 * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
 */

public class CommonParser extends FolderChildParser {

	protected CommonParser() {
        super();
    }

    protected CommonParser(final TimeZone timeZone) {
        super(timeZone);
    }

    protected CommonParser(final boolean parseAll, final TimeZone timeZone) {
        super(parseAll, timeZone);
    }

    protected void parseElementCommon(final CommonObject commonobject, final JSONObject jsonobject) throws JSONException, OXJSONException {
		if (jsonobject.has(CommonFields.CATEGORIES)) {
			commonobject.setCategories(parseString(jsonobject, CommonFields.CATEGORIES));
		}
		
		if (jsonobject.has(CommonFields.COLORLABEL)) {
			commonobject.setLabel(parseInt(jsonobject, CommonFields.COLORLABEL));
		}

		if (jsonobject.has(CommonFields.PRIVATE_FLAG)) {
			commonobject.setPrivateFlag(parseBoolean(jsonobject, CommonFields.PRIVATE_FLAG));
		}
		
		if (jsonobject.has(CommonFields.NUMBER_OF_ATTACHMENTS)) {
			commonobject.setNumberOfAttachments(parseInt(jsonobject, CommonFields.NUMBER_OF_ATTACHMENTS));
		}		

		parseElementFolderChildObject(commonobject, jsonobject);
	}
}

==> open-xchange-server_6.16.1.0.orig.tar.gz: open-xchange-server-6.16.1.0/src/com/openexchange/ajax/parser/CommonParser.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ajax.parser;

import java.util.TimeZone;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.ajax.fields.CommonFields;
import com.openexchange.groupware.container.CommonObject;
import com.openexchange.tools.servlet.OXJSONException;

/**
 * CommonParser
 *
 * @author <a href="mailto:sebastian.kauss@netline-is.de">Sebastian Kauss</a>
 */
public class CommonParser extends FolderChildParser {

    protected CommonParser() {
        super();
    }

    protected CommonParser(final TimeZone timeZone) {
        super(timeZone);
    }

    protected CommonParser(final boolean parseAll, final TimeZone timeZone) {
        super(parseAll, timeZone);
    }

    protected void parseElementCommon(final CommonObject obj, final JSONObject json) throws JSONException, OXJSONException {
        if (json.has(CommonFields.CATEGORIES)) {
            obj.setCategories(parseString(json, CommonFields.CATEGORIES));
        }
        
        if (json.has(CommonFields.COLORLABEL)) {
            obj.setLabel(parseInt(json, CommonFields.COLORLABEL));
        }

        if (json.has(CommonFields.PRIVATE_FLAG)) {
            obj.setPrivateFlag(parseBoolean(json, CommonFields.PRIVATE_FLAG));
        }
        
        if (json.has(CommonFields.NUMBER_OF_ATTACHMENTS)) {
            obj.setNumberOfAttachments(parseInt(json, CommonFields.NUMBER_OF_ATTACHMENTS));
        }        
        if (parseAll && json.has(CommonFields.LAST_MODIFIED_OF_NEWEST_ATTACHMENT_UTC)) {
            obj.setLastModifiedOfNewestAttachment(parseDate(json, CommonFields.LAST_MODIFIED_OF_NEWEST_ATTACHMENT_UTC));
        }
        parseElementFolderChildObject(obj, json);
    }
}
